PipelineParameters

Struct PipelineParameters 

pub struct PipelineParameters<'a> {
    pub vertex_binding_descriptions: Vec<VertexBindingDescription>,
    pub vertex_attribute_descriptions: Vec<VertexAttributeDescription>,
    pub descriptor_set_layouts: &'a [&'a DescriptorSetLayout],
    pub front_face: FrontFace,
    pub cull_mode: CullModeFlags,
}
Aditional parameters for Pipeline creation.

Fields

vertex_binding_descriptions: Vec<VertexBindingDescription>

BindingDescriptions of the vertex to be used by the pipeline.

vertex_attribute_descriptions: Vec<VertexAttributeDescription>

AttributeDescriptions of the vertex to be used by the pipeline.

descriptor_set_layouts: &'a [&'a DescriptorSetLayout]

DescriptorSetLayouts to be used by the pipeline.

front_face: FrontFace

Direction of the vertices to consider front-facing.

cull_mode: CullModeFlags

The orientation of triangles to cull.