pub struct DescriptorSet { /* private fields */ }Expand description
Holds a vk::DescriptorSet.
Implementations
Sourceimpl DescriptorSet
impl DescriptorSet
Sourcepub fn bind(
&self,
cmd_buffer: &CommandBuffer,
pipeline: &Pipeline,
first_set: u32,
dynamic_offsets: &[u32],
) -> Result<(), Error>
pub fn bind( &self, cmd_buffer: &CommandBuffer, pipeline: &Pipeline, first_set: u32, dynamic_offsets: &[u32], ) -> Result<(), Error>
Binds the DescriptorSet.
To be used when recording a command buffer, should be used after binding the pipeline. The
pipeline should be created with the same DescriptorSetLayout as this DescriptorSet.
dynamic_offsets must have the same length as the number of dynamic descriptors in this
set.
Examples
let descriptor_set = plate::DescriptorAllocator::new(&device).allocate(&layout, &pool)?;
// cmd_buffer.record(.., || {
// pipeline.bind(..);
descriptor_set.bind(&cmd_buffer, &pipeline, 0, &[]);
// })?;Auto Trait Implementations
impl Freeze for DescriptorSet
impl RefUnwindSafe for DescriptorSet
impl Send for DescriptorSet
impl Sync for DescriptorSet
impl Unpin for DescriptorSet
impl UnsafeUnpin for DescriptorSet
impl UnwindSafe for DescriptorSet